.. This is part of the Photini documentation.
   Copyright (C)  2012-19  Jim Easterbrook.
   See the file DOC_LICENSE.txt for copying conditions.

Further reading
===============

* The best explanation of what should be put in each metadata field I've found is the `Guide to Photo Metadata Fields <http://www.photometadata.org/META-Resources-Field-Guide-to-Metadata>`_.
* `Google Maps JavaScript API <https://developers.google.com/maps/documentation/javascript/tutorial>`_.
* `Bing Maps V8 Web Control <https://docs.microsoft.com/en-us/bingmaps/v8-web-control/>`_.
* `Leaflet, an open-source JavaScript library for mobile-friendly interactive maps <http://leafletjs.com/index.html>`_.
